// ***********************************************
// This example commands.js shows you how to
// create various custom commands and overwrite
// existing commands.
//
// For more comprehensive examples of custom
// commands please read more here:
// https://on.cypress.io/custom-commands
// ***********************************************
//
//
// -- This is a parent command --
// Cypress.Commands.add("login", (email, password) => { ... })
//
//
// -- This is a child command --
// Cypress.Commands.add("drag", { prevSubject: 'element'}, (subject, options) => { ... })
//
//
// -- This is a dual command --
// Cypress.Commands.add("dismiss", { prevSubject: 'optional'}, (subject, options) => { ... })
//
//
// -- This will overwrite an existing command --
// Cypress.Commands.overwrite("visit", (originalFn, url, options) => { ... })

import "@testing-library/cypress/add-commands";

Cypress.Commands.add("waitUntilNotLoading", () => {
  cy.findByTestId("full-page-spinner").should("not.exist");
  cy.findAllByText(/Loading/i).should("not.exist");
});

Cypress.Commands.add("isErrorBoxVisible", () => {
  cy.findByText(/Error!/i).should("be.visible");
});

Cypress.Commands.add("signUp", ({ email, password, customPrivateKey } = {}) => {
  cy.findByText(/Sign-Up/i).click();
  cy.findByPlaceholderText("hello@example.com").clear().type(email);
  cy.findByTestId("password").clear().type(password);
  if (customPrivateKey)
    cy.findByTestId("privateKey").clear().type(customPrivateKey);
  cy.findByText("Sign Up").click();
});

Cypress.Commands.add("signIn", ({ email, password }) => {
  cy.findByPlaceholderText("hello@example.com").clear().type(email);
  cy.findByTestId("password").clear().type(password);
  cy.findByText("Sign In").click();
});
